@@ -1,6 +1,6 @@
 /* gtkam-preview.c
  *
- * Copyright (C) 2001 Lutz Mller <urc8@rz.uni-karlsruhe.de>
+ * Copyright  2001 Lutz Mller <lutz@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,27 +18,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include "gtkam-preview.h"
-
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "i18n.h"
 
 #include <stdio.h>
 #include <string.h>
@@ -247,7 +229,9 @@ timeout_func (gpointer user_data)
 	if (p->priv->camera->multi)
 		gp_camera_exit (p->priv->camera->camera, NULL);
 	if (r < GP_OK) {
-		g_warning ("Could not capture: %s", gp_result_as_string (r));
+		if (r != GP_ERROR_CAMERA_BUSY)
+			g_warning ("Could not capture: %s",
+				   gp_result_as_string (r));
 		gp_file_unref (file);
 		return (TRUE);
 	}
