@@ -1,6 +1,6 @@
 /* gtkam-save.c
  *
- * Copyright  2001 Lutz Mller <lutz@users.sf.net>
+ * Copyright © 2001 Lutz Müller <lutz@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -16,7 +16,6 @@
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
- ADB WIP See if we can make this 'nicer'
  */
 
 #include "config.h"
@@ -27,7 +26,9 @@
 #include <string.h>
 #include <stdlib.h>
 
+#include <gtk/gtk.h>
 #include <gtk/gtktogglebutton.h>
+#include <gtk/gtkbutton.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkvbox.h>
 #include <gtk/gtkframe.h>
@@ -73,8 +74,8 @@ struct _GtkamSavePrivate
 	GtkWindow *main_window;
 };
 
-#define PARENT_TYPE GTK_TYPE_FILE_SELECTION
-static GtkFileSelection *parent_class;
+#define PARENT_TYPE GTK_TYPE_FILE_CHOOSER_DIALOG
+static GtkFileChooserDialog *parent_class;
 
 static void
 gtkam_save_destroy (GtkObject *object)
@@ -139,14 +140,14 @@ gtkam_save_get_type (void)
 	if (!type) {
 		GTypeInfo ti;
 
-        	memset (&ti, 0, sizeof (GTypeInfo));
-	        ti.class_size     = sizeof (GtkamSaveClass);
-	        ti.class_init     = gtkam_save_class_init;
-	        ti.instance_size  = sizeof (GtkamSave);
-	        ti.instance_init  = gtkam_save_init;
+		memset (&ti, 0, sizeof (GTypeInfo));
+		ti.class_size     = sizeof (GtkamSaveClass);
+		ti.class_init     = gtkam_save_class_init;
+		ti.instance_size  = sizeof (GtkamSave);
+		ti.instance_init  = gtkam_save_init;
 
-        	type = g_type_register_static (PARENT_TYPE, "GtkamSave",
-					       &ti, 0);
+		type = g_type_register_static (PARENT_TYPE, "GtkamSave",
+				&ti, 0);
 	}
 
 	return (type);
@@ -164,83 +165,46 @@ default_numbering_start(const GtkamSave *save)
 	GDir *dir;
 	const gchar *file;
 	gchar *tail,*prefix;
-	int max=1;
-	int plen,current;
+	int max = 1;
+	int plen, current;
 
-	if (!(dir=g_dir_open(gtk_file_selection_get_filename(
-		GTK_FILE_SELECTION(save)),0,NULL))) return 1;
-	prefix=g_strdup(gtk_entry_get_text(GTK_ENTRY(save->priv->prefix_entry)));
-	plen=strlen(prefix);
-	while ((file=g_dir_read_name(dir))) {
+	if (!(dir = g_dir_open (gtk_file_chooser_get_filename (
+		GTK_FILE_CHOOSER (save)) , 0, NULL))) return 1;
+	prefix = g_strdup (gtk_entry_get_text
+					(GTK_ENTRY (save->priv->prefix_entry)));
+	plen = strlen (prefix);
+	while ((file = g_dir_read_name (dir))) {
 		/* compare prefix */
-		if (strncmp(prefix,file,plen)) continue;
+		if (strncmp (prefix, file, plen)) continue;
 		/* check number */
-		current=strtol(file+plen,&tail,10);
-		if (tail - (file+plen) != 4) continue;
+		current = strtol (file+plen, &tail, 10);
+		if (tail - (file + plen) != 4) continue;
 		/* FIXME: check for regular file here */
-		if (max <= current) max = current+1;
+		if (max <= current) max = current + 1;
 	}
-	g_free(prefix);
-	g_dir_close(dir);
+	
+	g_free (prefix);
+	g_dir_close (dir);
 	return max;
 }
 
 static void
 on_filename_camera_toggled (GtkToggleButton *toggle, GtkamSave *save)
 {
-	switch (g_slist_length (save->priv->data)) {
-	case 1:
-
-		/*
-		 * Only one file to save - no prefix, no numbering. If the
-		 * button is toggled, users cannot specify a filename.
-		 */
-
-		gtk_widget_hide (save->priv->hbox_prefix);
-		gtk_widget_set_sensitive (save->priv->prefix_entry, FALSE);
-		gtk_widget_set_sensitive (save->priv->spin_entry, FALSE);
-
-		gtk_widget_show (GTK_FILE_SELECTION (save)->file_list);
-		gtk_widget_set_sensitive (GTK_FILE_SELECTION (save)->file_list,
-					  !toggle->active);
-
-		gtk_widget_show (GTK_FILE_SELECTION (save)->selection_entry);
-		gtk_widget_set_sensitive (
-			GTK_FILE_SELECTION (save)->selection_entry,
+	/*
+	 * Give the users the possibility to specify prefix and numbering.
+	 * No direct entry of filename is allowed.
+	 */
+	gtk_widget_show (save->priv->hbox_prefix);
+	gtk_widget_set_sensitive (GTK_WIDGET (save->priv->prefix_entry),
 			!toggle->active);
-
-		break;
-
-	default:
-
-		/*
-		 * More than one file to save. Give the users the possibility
-		 * to specify prefix and numbering. No direct entry of 
-		 * filename is allowed.
-		 */
-
-		gtk_widget_show (save->priv->hbox_prefix);
-		gtk_widget_set_sensitive (
-			GTK_WIDGET (save->priv->prefix_entry),
+	gtk_widget_set_sensitive (GTK_WIDGET (save->priv->spin_entry),
 			!toggle->active);
-		gtk_widget_set_sensitive (GTK_WIDGET (save->priv->spin_entry),
-			!toggle->active);
-		if (!toggle->active) {
-			/* calculate default start number */
-			gtk_spin_button_set_value (
-				GTK_SPIN_BUTTON (save->priv->spin_entry),
-				default_numbering_start(save));
-		}
-
-		gtk_widget_hide (GTK_FILE_SELECTION (save)->file_list);
-		gtk_widget_set_sensitive (GTK_FILE_SELECTION (save)->file_list,
-					  FALSE);
-
-		gtk_widget_hide (GTK_FILE_SELECTION (save)->selection_entry);
-		gtk_widget_set_sensitive (
-			GTK_FILE_SELECTION (save)->selection_entry, FALSE);
-
-		break;
+	if (!toggle->active) {
+		/* Calculate default start number */
+		gtk_spin_button_set_value (
+			GTK_SPIN_BUTTON (save->priv->spin_entry),
+			default_numbering_start (save));
 	}
 }
 
@@ -298,47 +262,38 @@ save_file (GtkamSave *save, CameraFile *file, guint n)
 	gp_file_get_mime_type (file, &mime_type);
 	gp_file_get_name (file, &filename);
 
-	fsel_path = gtk_file_selection_get_filename (GTK_FILE_SELECTION (save));
+	fsel_path = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER_DIALOG (save));
 
-	if (save->priv->toggle_filename_camera->active) {
+	if ((save->priv->toggle_filename_camera->active) ||
+		(g_slist_length (save->priv->data) == 1)) {
 
 		/* Use filename provided by the CameraFile */
 		full_filename = create_full_filename (filename, type);
-		full_path = concat_dir_and_file (fsel_path, full_filename);
+
+		if (g_slist_length (save->priv->data) == 1)
+			full_path = g_strdup(fsel_path);
+		else
+			full_path = concat_dir_and_file (fsel_path, full_filename);
+
 		g_free (full_filename);
 
 	} else {
-		if (g_slist_length (save->priv->data) == 1) {
+		/* Use filename in prefix */
+		prefix = g_locale_from_utf8 (gtk_entry_get_text
+					(GTK_ENTRY (save->priv->prefix_entry)), -1,
+					NULL, NULL, NULL);
 
-			/* Use filename provided by the GtkFileSelection */
-			fsel_filename = g_path_get_basename (fsel_path);
-
-			full_filename = create_full_filename (fsel_filename,
-							      type);
-			dirname = g_path_get_dirname (fsel_path);
-			full_path = concat_dir_and_file (dirname,
-							 full_filename);
-			g_free (dirname);
-			g_free (full_filename);
+		suffix = strrchr (mime_type, '/');
+		suffix++;
+		number_filename = g_strdup_printf ("%s%04i.%s", prefix,
+								n, suffix);
+		full_filename = create_full_filename (number_filename,
+								type);
+		g_free (number_filename);
 		
-		} else {
-
-			/* Use filename in prefix */
-			prefix = gtk_entry_get_text (
-					GTK_ENTRY (save->priv->prefix_entry));
-			if (!g_strcasecmp (prefix, "")) prefix = _("photo");
-
-			suffix = strrchr (mime_type, '/');
-			suffix++;
-			number_filename = g_strdup_printf ("%s%04i.%s", prefix,
-							   n, suffix);
-			full_filename = create_full_filename (number_filename,
-							      type);
-			g_free (number_filename);
-			full_path = concat_dir_and_file (fsel_path,
-							 full_filename);
-			g_free (full_filename);
-		}
+		full_path = concat_dir_and_file (fsel_path,
+							full_filename);
+		g_free (full_filename);
 	}
 
 	/* FIXME Check which is user, and prompt the user */
@@ -360,6 +315,7 @@ save_file (GtkamSave *save, CameraFile *file, guint n)
 	/* FIXME Check for sufficient disk space for this file, or
 	   calculate total disk space required for all files before
 	   save process starts */
+
 	result = gp_file_save (file, full_path);
 	if (result < 0) {
 		if (!save->priv->err_shown) {
@@ -422,19 +378,22 @@ store_save_settings(GtkamSave *save)
 	gchar *savedir,*t;
 	gchar buf[5];
 
-	/* directory */
-	savedir=g_strdup(gtk_file_selection_get_filename(
-			      GTK_FILE_SELECTION (save)));
+	/* Directory */
+	savedir = g_strdup (gtk_file_chooser_get_filename (
+			      GTK_FILE_CHOOSER_DIALOG (save)));
 	if (savedir) {
-		if (strlen(savedir) > 255) savedir[255]='\0';
-		if (!g_file_test(savedir,G_FILE_TEST_IS_DIR)) {
-			t=g_path_get_dirname(savedir);
-			g_free(savedir);
-			savedir=t;
+		if (strlen (savedir) > 255)
+			savedir[255] = '\0';
+
+		if (!g_file_test (savedir, G_FILE_TEST_IS_DIR)) {
+			t = g_path_get_dirname (savedir);
+			g_free (savedir);
+			savedir = t;
 		}
-		gp_setting_set("gtkam","save-dir",savedir);
-		g_free(savedir);
+		gp_setting_set ("gtkam", "save-dir", savedir);
+		g_free (savedir);
 	}
+	
 	/* toggle buttons */
 #define STORE_TOGGLE(NAME) \
 	snprintf(buf,sizeof(buf), "%d", gtk_toggle_button_get_active(	\
@@ -447,11 +406,12 @@ store_save_settings(GtkamSave *save)
 	STORE_TOGGLE(audio);
 	STORE_TOGGLE(exif);
 	STORE_TOGGLE(filename_camera);
+
 	/* prefix entry */
 	if (g_slist_length (save->priv->data) > 1) {
 		/* only when saving several files */
-		gp_setting_set("gtkam","save-prefix",(gchar *)
-			gtk_entry_get_text(GTK_ENTRY(save->priv->prefix_entry)));
+		gp_setting_set("gtkam", "save-prefix", (gchar *)
+			gtk_entry_get_text (GTK_ENTRY (save->priv->prefix_entry)));
 	}
 }
 
@@ -463,16 +423,16 @@ load_save_settings(GtkamSave *save)
 
 	/* directory */
 	if (gp_setting_get("gtkam","save-dir",buf) == GP_OK) {
-		dir=g_strdup(buf);
-		strcat(buf,G_DIR_SEPARATOR_S);
-		gtk_file_selection_set_filename(GTK_FILE_SELECTION(save),buf);
+		dir = g_strdup (buf);
+		strcat (buf, G_DIR_SEPARATOR_S);
+		gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (save), buf);
 	} else {
-		dir=g_strdup(gtk_file_selection_get_filename(
-			GTK_FILE_SELECTION(save) ));
+		dir = g_strdup (gtk_file_chooser_get_filename (
+			GTK_FILE_CHOOSER (save)));
 	}
 	/* prefix entry */
-	gp_setting_get("gtkam","save-prefix",buf);
-	gtk_entry_set_text(GTK_ENTRY(save->priv->prefix_entry), buf);
+	gp_setting_get ("gtkam", "save-prefix", buf);
+	gtk_entry_set_text (GTK_ENTRY (save->priv->prefix_entry), buf);
 
 	/* toggle buttons */
 #define LOAD_TOGGLE(NAME) \
@@ -488,18 +448,56 @@ load_save_settings(GtkamSave *save)
 	g_free(dir);
 }
 
+static int
+count_items (GtkamSave *save)
+{
+	int items_to_save = 0;
+	
+	if (save->priv->toggle_normal &&
+		    save->priv->toggle_normal->active)
+		items_to_save++;
+
+	if (save->priv->toggle_preview &&
+	    save->priv->toggle_preview->active)
+		items_to_save++;
+
+	if (save->priv->toggle_raw &&
+	    save->priv->toggle_raw->active)
+		items_to_save++;
+
+	if (save->priv->toggle_audio &&
+	    save->priv->toggle_audio->active)
+		items_to_save++;
+
+	if (save->priv->toggle_exif &&
+	    save->priv->toggle_exif->active)
+		items_to_save++;
+
+	return items_to_save;
+}
 
 static void
 on_ok_clicked (GtkButton *button, GtkamSave *save)
 {
 	guint i, count, j = 1;
-	int result;
+	int result = -1;
 	GtkWidget *s, *dialog;
 	unsigned int id = 0;
 	GtkamSaveData *data;
 	gchar *progname, *command;
 	GError *error;
 
+	if (count_items (save) == 0) {
+		if (!save->priv->err_shown) {
+			
+			dialog = gtkam_error_new (result, NULL,
+					GTK_WIDGET (save), _("There is nothing to be saved."));
+			gtk_widget_show (dialog);
+		}
+
+		return;
+	}
+			
 	store_save_settings(save);
 	gtk_widget_hide (GTK_WIDGET (save));
 
@@ -617,27 +615,39 @@ GtkWidget *
 gtkam_save_new (GtkWindow *main_window)
 {
 	GtkamSave *save;
-	GtkWidget *hbox, *frame, *check, *label, *entry;
+	GtkWidget *hbox, *frame, *main_vbox, *check, *label, *entry, *button;
 	GtkObject *a;
 	GtkTooltips *tooltips;
 
 	save = g_object_new (GTKAM_TYPE_SAVE, NULL);
 
-	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (save)->ok_button),
-			    "clicked", G_CALLBACK (on_ok_clicked), save);
-	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (save)->cancel_button),
-			  "clicked", G_CALLBACK (on_cancel_clicked), save);
+	button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+	gtk_widget_show (button);
+	g_signal_connect (GTK_OBJECT (button),
+			  "clicked", GTK_SIGNAL_FUNC (on_cancel_clicked), save);
+	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (save)->action_area),
+			   button);
+
+	button = gtk_button_new_from_stock (GTK_STOCK_OK);
+	gtk_widget_show (button);
+	g_signal_connect (GTK_OBJECT (button), "clicked",
+			    GTK_SIGNAL_FUNC (on_ok_clicked), save);
+	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (save)->action_area),
+			   button);
 	
 	tooltips = gtk_tooltips_new ();
 
 	frame = gtk_frame_new (_("What to save:"));
 	gtk_widget_show (frame);
-	gtk_box_pack_start (GTK_BOX (GTK_FILE_SELECTION (save)->main_vbox),
-			    frame, FALSE, FALSE, 0);
+	gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (save), frame);
+
+	main_vbox = gtk_vbox_new (TRUE, 5);
+	gtk_widget_show (main_vbox);
+	gtk_container_add (GTK_CONTAINER (frame), main_vbox);
 
 	hbox = gtk_hbox_new (TRUE, 5);
 	gtk_widget_show (hbox);
-	gtk_container_add (GTK_CONTAINER (frame), hbox);
+	gtk_container_add (GTK_CONTAINER (main_vbox), hbox);
 
 	check = gtk_check_button_new_with_label (_("Save photos"));
 	gtk_widget_show (check);
@@ -677,7 +687,7 @@ gtkam_save_new (GtkWindow *main_window)
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (hbox);
-	gtk_box_pack_start (GTK_BOX (GTK_FILE_SELECTION (save)->main_vbox),
+	gtk_box_pack_start (GTK_BOX (main_vbox),
 			    hbox, TRUE, TRUE, 0);
 
 	label = gtk_label_new (_("Open image(s) with: "));
@@ -695,7 +705,7 @@ gtkam_save_new (GtkWindow *main_window)
 	/* Filenames provided by camera */
 	check = gtk_check_button_new_with_label (_("Use filename(s) provided by the camera"));
 	gtk_widget_show (check);
-	gtk_box_pack_start (GTK_BOX (GTK_FILE_SELECTION (save)->main_vbox),
+	gtk_box_pack_start (GTK_BOX (main_vbox),
 			    check, TRUE, TRUE, 0);
 	gtk_tooltips_set_tip (tooltips, check, _("Choose whether to use the "
 			      "filename provided by the camera"), NULL);
@@ -705,35 +715,33 @@ gtkam_save_new (GtkWindow *main_window)
 			  G_CALLBACK (on_filename_camera_toggled), save);
 
 	hbox = gtk_hbox_new (FALSE, 5);
-        gtk_widget_show (hbox);
-        gtk_box_pack_start (GTK_BOX (GTK_FILE_SELECTION (save)->main_vbox),
-                            hbox, TRUE, TRUE, 0);
-        gtk_box_reorder_child (GTK_BOX (GTK_FILE_SELECTION (save)->main_vbox),
-                               hbox, 256);
+	gtk_widget_show (hbox);
+	gtk_box_pack_start (GTK_BOX (main_vbox),
+			    hbox, TRUE, TRUE, 0);
+
 	save->priv->hbox_prefix = hbox;
 
-        label = gtk_label_new (_("Filename prefix: "));
-        gtk_widget_show (label);
-        gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	label = gtk_label_new (_("Filename prefix: "));
+	gtk_widget_show (label);
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
 	save->priv->prefix_entry = gtk_entry_new ();
-        gtk_widget_show (save->priv->prefix_entry);
-        gtk_box_pack_start (GTK_BOX (hbox), save->priv->prefix_entry,
+	gtk_widget_show (save->priv->prefix_entry);
+	gtk_box_pack_start (GTK_BOX (hbox), save->priv->prefix_entry,
 			    TRUE, TRUE, 0);
 
 	label = gtk_label_new (_("Start numbering with: "));
-        gtk_widget_show (label);
-        gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	gtk_widget_show (label);
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
 	a = gtk_adjustment_new (1.0, 1.0, 10000.0, 1.0, 10.0, 10.0);
 	save->priv->spin_entry = gtk_spin_button_new (GTK_ADJUSTMENT (a),
 				 1.0, 0);
-        gtk_widget_show (save->priv->spin_entry);
-        gtk_box_pack_start (GTK_BOX (hbox), save->priv->spin_entry,
+	gtk_widget_show (save->priv->spin_entry);
+	gtk_box_pack_start (GTK_BOX (hbox), save->priv->spin_entry,
 			    FALSE, FALSE, 0);
 
 	load_save_settings(save);
-	gtk_widget_grab_focus (GTK_FILE_SELECTION (save)->ok_button);
 
 	/* Remember the main window (if given) */
 	save->priv->main_window = main_window ? main_window : GTK_WINDOW (save);
@@ -768,18 +776,16 @@ gtkam_save_add (GtkamSave *save, GtkamCamera *camera,
 		gtk_window_set_title (GTK_WINDOW (save), title);
 		g_free (title);
 
+		gtk_widget_hide (save->priv->toggle_filename_camera);
+	
 		gtk_widget_hide (save->priv->hbox_prefix);
 		gtk_widget_set_sensitive (save->priv->spin_entry, FALSE);
 		gtk_widget_set_sensitive (save->priv->prefix_entry, FALSE);
 
-		gtk_widget_show (GTK_FILE_SELECTION (save)->file_list);
-		gtk_widget_set_sensitive (GTK_FILE_SELECTION (save)->file_list,
-				!save->priv->toggle_filename_camera->active);
+		gtk_file_chooser_set_action(GTK_FILE_CHOOSER (save),
+				GTK_FILE_CHOOSER_ACTION_SAVE);
 
-		gtk_widget_show (GTK_FILE_SELECTION (save)->selection_entry);
-		gtk_widget_set_sensitive (
-			GTK_FILE_SELECTION (save)->selection_entry,
-			!save->priv->toggle_filename_camera->active);
+		gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (save), name);
 
 		break;
 
@@ -788,19 +794,15 @@ gtkam_save_add (GtkamSave *save, GtkamCamera *camera,
 		/* Second case: We have multiple files to save. */
 		gtk_window_set_title (GTK_WINDOW (save), _("Save photos..."));
 
+		gtk_widget_show (save->priv->toggle_filename_camera);
+
 		gtk_widget_show (save->priv->hbox_prefix);
 		gtk_widget_set_sensitive (save->priv->spin_entry,
 				!save->priv->toggle_filename_camera->active);
 		gtk_widget_set_sensitive (save->priv->prefix_entry,
 				!save->priv->toggle_filename_camera->active);
-
-		gtk_widget_hide (GTK_FILE_SELECTION (save)->file_list);
-		gtk_widget_set_sensitive (GTK_FILE_SELECTION (save)->file_list,
-					  FALSE);
-
-		gtk_widget_hide (GTK_FILE_SELECTION (save)->selection_entry);
-	        gtk_widget_set_sensitive (
-			GTK_FILE_SELECTION (save)->selection_entry, FALSE);
+		gtk_file_chooser_set_action(GTK_FILE_CHOOSER (save),
+				GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
 
 		break;
 	}
