@@ -1,6 +1,6 @@
 /* gtkam-util.c
  *
- * Copyright (C) 2001 Lutz Mller <urc8@rz.uni-karlsruhe.de>
+ * Copyright  2001 Lutz Mller <lutz@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -17,32 +17,14 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include <config.h>
+#include "config.h"
 #include "gtkam-util.h"
+#include "i18n.h"
 
 #include <gdk-pixbuf/gdk-pixbuf-loader.h>
 
 #include "gtkam-close.h"
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
-
 GdkPixbuf *
 gdk_pixbuf_new_from_camera_file (CameraFile *file, guint max_dim,
 				 GtkWidget *opt_window)
